==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridScrollEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebGridScrollEventArgsDetailDescription } from "./WebGridScrollEventArgsDetailDescription";
/**
 * @hidden
 */
var WebGridScrollEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridScrollEventArgsDetailDescriptionMetadata, _super);
    function WebGridScrollEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridScrollEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebGridScrollEventArgsDetailDescriptionMetadata.a == null) {
            WebGridScrollEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridScrollEventArgsDetailDescriptionMetadata.c(WebGridScrollEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebGridScrollEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridScrollEventArgsDetailDescriptionMetadata.a);
    };
    WebGridScrollEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridScrollEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Direction", "String");
        a.item("ScrollPosition", "Number:double");
    };
    WebGridScrollEventArgsDetailDescriptionMetadata.d = function (a) {
        WebGridScrollEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebGridScrollEventArgsDetail", function () { return new WebGridScrollEventArgsDetailDescription(); });
        a.z("WebGridScrollEventArgsDetail", WebGridScrollEventArgsDetailDescriptionMetadata.a);
    };
    WebGridScrollEventArgsDetailDescriptionMetadata.$t = markType(WebGridScrollEventArgsDetailDescriptionMetadata, 'WebGridScrollEventArgsDetailDescriptionMetadata');
    WebGridScrollEventArgsDetailDescriptionMetadata.a = null;
    return WebGridScrollEventArgsDetailDescriptionMetadata;
}(Base));
export { WebGridScrollEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridScrollEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebGridScrollEventArgsDetailDescription } from "./WebGridScrollEventArgsDetailDescription";
/**
 * @hidden
 */
var WebGridScrollEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridScrollEventArgsDetailDescriptionMetadata, _super);
    function WebGridScrollEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridScrollEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebGridScrollEventArgsDetailDescriptionMetadata.a == null) {
            WebGridScrollEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridScrollEventArgsDetailDescriptionMetadata.c(WebGridScrollEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebGridScrollEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridScrollEventArgsDetailDescriptionMetadata.a);
    };
    WebGridScrollEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridScrollEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Direction", "String");
        a.item("ScrollPosition", "Number:double");
    };
    WebGridScrollEventArgsDetailDescriptionMetadata.d = function (a) {
        WebGridScrollEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebGridScrollEventArgsDetail", function () { return new WebGridScrollEventArgsDetailDescription(); });
        a.ab("WebGridScrollEventArgsDetail", WebGridScrollEventArgsDetailDescriptionMetadata.a);
    };
    WebGridScrollEventArgsDetailDescriptionMetadata.$t = markType(WebGridScrollEventArgsDetailDescriptionMetadata, 'WebGridScrollEventArgsDetailDescriptionMetadata');
    WebGridScrollEventArgsDetailDescriptionMetadata.a = null;
    return WebGridScrollEventArgsDetailDescriptionMetadata;
}(Base));
export { WebGridScrollEventArgsDetailDescriptionMetadata };
